==> dcoupon_sdk_flutter_package-8.0.1.tar.gz: lib/src/data/helpers/publisher_api_helper.dart <==
import 'package:dcoupon_sdk_flutter_package/src/config_reader.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/device_info.dart';
import 'package:dcoupon_sdk_flutter_package/src/data/helpers/authorization_helper.dart';
import 'package:dcoupon_sdk_flutter_package/src/utils/constants.dart';
import 'package:dcoupon_sdk_flutter_package/src/utils/enum_helper.dart';

const String VERSION = "v3";

const String API_PATH_NAME = '/publisher';

const Map<String, String> URLS_BY_ENVIRONMENT = {
  'dev': 'https://services-dev.dcoupon.com',
  'dcoupon.eu': 'https://services.dcoupon.eu',
  'dcoupon-latam.com': 'https://services-latam.dcoupon.com',
  'dcoupon.com': 'https://services.dcoupon.com'
};

class PublisherApiHelper {
  static Map<String, dynamic> buildHeaders() {
    var headers = <String, dynamic>{};

    final currentDateFormatted = AuthorizationHelper.getCurrentDateFormatted();

    headers[Constants.HEADER_AUTH_METHOD] =
        EnumHelper.enumToString(AuthMethod.SIGNATURE);
    headers[Constants.HEADER_AUTH_TIMESTAMP] = currentDateFormatted;
    headers[Constants.HEADER_AUTH_APIKEY] = ConfigReader.clientApiToken;
    headers[Constants.HEADER_AUTH_SIGNATURE] =
        AuthorizationHelper.getAuthSignature(currentDateFormatted);

    return headers;
  }

  static String getEndpointUrl() {
    if (DevicePlatform.isWeb && ConfigReader.webOrigin != null) {
      return ConfigReader.webOrigin!;
    }
    return URLS_BY_ENVIRONMENT[ConfigReader.clientDomain!]!;
  }

  static String getStoresUrl() {
    const methodPath = '/$VERSION/stores';
    return getEndpointUrl() + API_PATH_NAME + methodPath;
  }

  static String getPromotionsUrl() {
    const methodPath = '/$VERSION/promotions';
    return getEndpointUrl() + API_PATH_NAME + methodPath;
  }

  static String getPromotionDetailUrl(String promotionToken) {
    final methodPath = '/$VERSION/promotion/$promotionToken';
    return getEndpointUrl() + API_PATH_NAME + methodPath;
  }

  static String getRetailersUrl() {
    const methodPath = '/$VERSION/retailers';
    return getEndpointUrl() + API_PATH_NAME + methodPath;
  }

  static String getCategoriesUrl() {
    const methodPath = '/$VERSION/categories';
    return getEndpointUrl() + API_PATH_NAME + methodPath;
  }

  static String getCompaniesUrl() {
    const methodPath = '/$VERSION/companies';
    return getEndpointUrl() + API_PATH_NAME + methodPath;
  }
}

==> dcoupon_sdk_flutter_package-9.1.0.tar.gz: lib/src/data/helpers/publisher_api_helper.dart <==
import 'package:dcoupon_sdk_flutter_package/src/config_reader.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/device_info.dart';
import 'package:dcoupon_sdk_flutter_package/src/data/helpers/authorization_helper.dart';
import 'package:dcoupon_sdk_flutter_package/src/utils/constants.dart';
import 'package:dcoupon_sdk_flutter_package/src/utils/enum_helper.dart';

const String VERSION = "v3";

const String API_PATH_NAME = '/publisher';

const Map<String, String> URLS_BY_ENVIRONMENT = {
  'dev': 'https://services-dev.dcoupon.com',
  'dcoupon.eu': 'https://services.dcoupon.eu',
  'dcoupon-latam.com': 'https://services-latam.dcoupon.com',
  'dcoupon.com': 'https://services.dcoupon.com'
};

class PublisherApiHelper {
  static Map<String, dynamic> buildHeaders() {
    var headers = <String, dynamic>{};

    final currentDateFormatted = AuthorizationHelper.getCurrentDateFormatted();

    headers[Constants.HEADER_AUTH_METHOD] =
        EnumHelper.enumToString(AuthMethod.SIGNATURE);
    headers[Constants.HEADER_AUTH_TIMESTAMP] = currentDateFormatted;
    headers[Constants.HEADER_AUTH_APIKEY] = ConfigReader.dcouponSDKOptions.clientApiToken;
    headers[Constants.HEADER_AUTH_SIGNATURE] =
        AuthorizationHelper.getAuthSignature(currentDateFormatted);

    return headers;
  }

  static String getEndpointUrl() {
    if (DevicePlatform.isWeb && ConfigReader.dcouponSDKOptions.webOrigin != null) {
      return ConfigReader.dcouponSDKOptions.webOrigin!;
    }
    return URLS_BY_ENVIRONMENT[ConfigReader.dcouponSDKOptions.clientDomain]!;
  }

  static String getStoresUrl() {
    const methodPath = '/$VERSION/stores';
    return getEndpointUrl() + API_PATH_NAME + methodPath;
  }

  static String getPromotionsUrl() {
    const methodPath = '/$VERSION/promotions';
    return getEndpointUrl() + API_PATH_NAME + methodPath;
  }

  static String getPromotionDetailUrl(String promotionToken) {
    final methodPath = '/$VERSION/promotion/$promotionToken';
    return getEndpointUrl() + API_PATH_NAME + methodPath;
  }

  static String getRetailersUrl() {
    const methodPath = '/$VERSION/retailers';
    return getEndpointUrl() + API_PATH_NAME + methodPath;
  }

  static String getCategoriesUrl() {
    const methodPath = '/$VERSION/categories';
    return getEndpointUrl() + API_PATH_NAME + methodPath;
  }

  static String getCompaniesUrl() {
    const methodPath = '/$VERSION/companies';
    return getEndpointUrl() + API_PATH_NAME + methodPath;
  }
}
